==> openg-6.x-1.0.tar.gz: openg/theme-settings.php <==
<?php
// $Id: theme-settings.php,v 1.5 2010/08/14 00:25:31 mauro72 Exp $

/**
 * Theme setting defaults
 */
function opengrid_default_theme_settings() {
  $defaults = array(
    'css_switch' => 0,
    'opengrid_js_control'=> 0,
    'scroll_to_top' => 0,
    'fixed_buttons' => 0,
    'frontpage_layout_checkbox' => 0,    
  );

  // Add site-wide theme settings
  $defaults = array_merge($defaults, theme_get_settings());

  return $defaults;
}

/**
 * Initialize theme settings if needed
 */
function opengrid_initialize_theme_settings($theme_name) {
  $theme_settings = theme_get_settings($theme_name);
  if (!isset($theme_settings['css_switch']) || $theme_settings['opengrid_rebuild_registry'] == 1) {
    static $registry_rebuilt = false;   // avoid multiple rebuilds per page

    // Rebuild theme registry & notify user
    if(isset($theme_settings['opengrid_rebuild_registry']) && $theme_settings['opengrid_rebuild_registry'] == 1 && !$registry_rebuilt) {
      drupal_rebuild_theme_registry();
      drupal_set_message(t('Theme registry rebuild completed. <a href="!link">Turn off</a> this feature for production websites.', array('!link' => url('admin/build/themes/settings/' . $GLOBALS['theme']))), 'warning');
      $registry_rebuilt = true;
    }

    // Retrieve saved or site-wide theme settings
    $theme_setting_name = str_replace('/', '_', 'theme_'. $theme_name .'_settings');
    $settings = (variable_get($theme_setting_name, FALSE)) ? theme_get_settings($theme_name) : theme_get_settings();

    // Skip toggle_node_info_ settings
    if (module_exists('node')) {
      foreach (node_get_types() as $type => $name) {
        unset($settings['toggle_node_info_'. $type]);
      }
    }

    // Combine default theme settings from .info file & theme-settings.php
    $theme_data = list_themes();   // get theme data for all themes
    $info_theme_settings = ($theme_name) ? $theme_data[$theme_name]->info['settings'] : array();
    $defaults = array_merge(opengrid_default_theme_settings(), $info_theme_settings);

    // Set combined default & saved theme settings
    variable_set($theme_setting_name, array_merge($defaults, $settings));

    // Force theme settings refresh
    theme_get_setting('', TRUE);
  }
}

/**
 * Implementation of THEMEHOOK_settings() function.
 *
 * @param $saved_settings
 *   An array of saved settings for this theme.
 * @return
 *   A form array.
 */
function opengrid_settings($saved_settings, $subtheme_defaults = array()) {

  global $base_url;
  
  // Get theme name from url (admin/.../theme_name)
  $theme_name = arg(count(arg()) - 1);
  
  // Combine default theme settings from .info file & theme-settings.php
  $theme_data = list_themes();   // get data for all themes
  $info_theme_settings = ($theme_name) ? $theme_data[$theme_name]->info['settings'] : array();
  $defaults = array_merge(opengrid_default_theme_settings(), $info_theme_settings);

  // Allow a subtheme to override the default values.
  $defaults = array_merge($defaults, $subtheme_defaults); 

  // Combine default and saved theme settings
  $settings = array_merge($defaults, $saved_settings);
  
  // Create the form using Forms API: http://api.drupal.org/api/6
  $form = array();

  $form['opengrid_rebuild_registry'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Rebuild theme registry on every page.'),
    '#default_value' => $settings['opengrid_rebuild_registry'],
    '#description'   => t('During theme development, it can be very useful to continuously <a href="!link">rebuild the theme registry</a>. WARNING: this is a huge performance penalty and must be turned off on production websites.', array('!link' => 'http://drupal.org/node/173880#theme-registry')),
    '#prefix'        => '<div id="div-zen-registry"><strong>' . t('Theme registry:') . '</strong>',
    '#suffix'        => '</div>',
  );

  $form['scroll_to_top'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Scroll to top Button.'),
    '#default_value' => $settings['scroll_to_top'],
  );
  
  $form['fixed_buttons'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Fixed Submit buttons.'),
    '#default_value' => $settings['fixed_buttons'],
    '#description' => t('Set a fixed position for submit buttons on node forms(useful in long forms).'),
  );  

  $form['frontpage_layout_checkbox'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Front Page Layout.'),
    '#default_value' => $settings['frontpage_layout_checkbox'],
    '#description' => t('Set an exclusive layout for the front page.'),
  ); 

  //primary and secondary links

  $form['main_navigation'] = array(
    '#type' => 'fieldset',
    '#title' => t('Grid Settings for Primary & Secondary Links wrapper.'),
  );
  $form['main_navigation']['primary_dropdown'] = array(
    '#type' => 'checkbox',
    '#title' => t('Dropdown Menu'),
    '#default_value' => $settings['primary_dropdown'],
    '#prefix' => '<div class="inline-label">',
    '#suffix' => '</div>',  
  );
  $form['main_navigation']['navigation_extras'] = array(
    '#type' => 'textfield',
    '#title' => t('Extra classes'),
    '#size' => 20,
    '#default_value' => $settings['navigation_extras'],
    '#prefix' => '<div class="inline-label">',
    '#suffix' => '</div>',
  );
  
  $nav_classes = array('none' => 'none','emac' => 'emac','drupal1' => 'drupal1','simpleTabs' => 'Simple Tabs');
  $form['main_navigation']['navigation_classes'] = array(
    '#type' => 'select',
    '#title' => t('Default classes'),
    '#options' => $nav_classes,
    '#default_value' => $settings['navigation_classes'],
    '#prefix' => '<div class="inline-label">',
    '#suffix' => '</div>',
  );  

  //containers settings form

  $form['containers_fieldset'] = array(
    '#type' => 'fieldset',
    '#title' => t('Container Settings'),
    '#collapsible' => TRUE,
    '#description' => t('Container define the number of columns in wich is split the screen.'),
  );
  
  $form['containers_fieldset']['container_columns'] = array(
    '#type' => 'select',
    '#title' => t('Grid columns'),
    '#attributes' => array('class' => 'input-inline'),
    '#options' => array('none' => t('none'),'container_12' => t('12'), 'container_16' => t('16'), 'container_24' => t('24')),
    '#default_value' => $settings['container_columns'],
    '#prefix' => '<div class="inline-label">',
    '#suffix' => '</div>',    
  );
  
  $form['containers_fieldset']['css_switch'] = array(
    '#type' => 'select',
    '#title' => t('Select CSS'),
    '#options' => array(t('fixed'), t('fluid')),
    '#default_value' => $settings['css_switch'],
    '#prefix' => '<div class="inline-label">',
    '#suffix' => '</div>',    
  );  
  
  $form['containers_fieldset']['container_extras'] = array(
    '#type' => 'textfield',
    '#title' => t('Container extras'),
    '#attributes' => array('class' => 'input-inline'),
    '#size' => 20,
    '#default_value' => $settings['container_extras'],
    '#prefix' => '<div class="inline-label">',
    '#suffix' => '</div>',    
  );    
  
  $form['containers_fieldset']['independent_containers'] = array(
    '#type' => 'checkbox',
    '#title' => t('Container by Region'),
    '#description' => t('Set Independent Containers for each Region, this is usefull for design that needs full screen width backgrounds.'),
    '#default_value' => $settings['independent_containers'],
    '#prefix' => '<div class="inline-label">',
    '#suffix' => '</div>',    
  );

  // grid settings form

  $grid_options = array(
    'header',
    'content_top',
    'content',
    'main',
    'first_sidebar',
    'second_sidebar',
    'content_bottom',
    'footer',
  );

  $layouts = array(
    'both_sidebars',
    'first_sidebar',
    'second_sidebar',
    'no_sidebars',
    'frontpage'
  );
  $form['help_message'] = array(
    '#type' => 'markup',
    '#value' => '<h3>'. t('Pre-configuration for layout based on active sidebars.') .'</h3>',
  );
  
  foreach ($layouts as $key) {
    $new_grid_options = $grid_options;
    if ($key == 'no_sidebars' || $key == 'first_sidebar') {
      unset($new_grid_options[5]);
    }
    if ($key == 'no_sidebars' || $key == 'second_sidebar') {
      unset($new_grid_options[4]);
    }

    $name = str_replace('_', ' ',$key);
    $form[$key .'_layout'] = array(
      '#type' => 'fieldset',
      '#title' => t('@name Active', array('@name' => $name)),
      '#collapsible' => true,
      '#collapsed' => true,
      '#tree' => true,
    );

    // Grids Fieldset
    $form[$key .'_layout']['grids_settings'] = array(
      '#type' => 'fieldset',
      '#theme' => 'grids_settings_table',
    );
    $max_columns = ($settings['container_columns'] == 'container_12') ? 12 : 16;
    $max_columns = ($settings['container_columns'] == 'container_24') ? 24 : 16;    
    for ($i = 0; $i <= $max_columns; $i++) {
      $options_16[$i] = $i == 0 ? t('none') : $i;
    }

    foreach ($new_grid_options as $key_region) {
      $name = str_replace('_', ' ',$key_region);
      $form[$key .'_layout']['grids_settings'][$key_region .'_grid']['grid'] = array(
        '#type' => 'select',
        '#title' => t('@name', array('@name' => $name)),
        '#attributes' => array('class' => 'input-inline'),
        '#options' => $options_16,
        '#default_value' => $settings[$key .'_layout']['grids_settings'][$key_region .'_grid']['grid'],
      );

      // prefix, suffix settings
      $form[$key .'_layout']['grids_settings'][$key_region .'_grid']['prefix'] = array(
        '#type' => 'select',
        '#attributes' => array('class' => 'input-inline'),
        '#options' => $options_16,
        '#default_value' => $settings[$key .'_layout']['grids_settings'][$key_region .'_grid']['prefix'],
      );

      $form[$key .'_layout']['grids_settings'][$key_region .'_grid']['suffix'] = array(
        '#type' => 'select',
        '#attributes' => array('class' => 'input-inline'),
        '#options' => $options_16,
        '#default_value' => $settings[$key .'_layout']['grids_settings'][$key_region .'_grid']['suffix'],
      );

      // push , pulls selects
      $form[$key .'_layout']['grids_settings'][$key_region .'_grid']['push'] = array(
        '#type' => 'select',
        '#attributes' => array('class' => 'input-inline'),
        '#options' => $options_16,
        '#default_value' => $settings[$key .'_layout']['grids_settings'][$key_region .'_grid']['push'],
      );

      $form[$key .'_layout']['grids_settings'][$key_region .'_grid']['pull'] = array(
        '#type' => 'select',
        '#attributes' => array('class' => 'input-inline'),
        '#options' => $options_16,
        '#default_value' => $settings[$key .'_layout']['grids_settings'][$key_region .'_grid']['pull'],
      );

      // alpha, omega checkboxes
      $form[$key .'_layout']['grids_settings'][$key_region .'_grid']['alpha'] = array(
        '#type' => 'checkbox',
        '#attributes' => array('class' => 'input-inline'),
        '#default_value' => $settings[$key .'_layout']['grids_settings'][$key_region .'_grid']['alpha'],
      );

      $form[$key .'_layout']['grids_settings'][$key_region .'_grid']['omega'] = array(
        '#type' => 'checkbox',
        '#attributes' => array('class' => 'input-inline'),
        '#default_value' => $settings[$key .'_layout']['grids_settings'][$key_region .'_grid']['omega'],
      );

      // extra classes textfield
      $form[$key .'_layout']['grids_settings'][$key_region .'_grid']['extras'] = array(
        '#type' => 'textfield',
        '#attributes' => array('class' => 'input-inline'),
        '#size' => 10,
        '#default_value' => $settings[$key .'_layout']['grids_settings'][$key_region .'_grid']['extras'],
      );
    }
  }

  return $form;
}

==> openg-6.x-1.1.tar.gz: openg/theme-settings.php <==
<?php
// $Id: theme-settings.php,v 1.7 2010/10/04 14:38:27 mauro72 Exp $

/**
 * Theme setting defaults
 */
function opengrid_default_theme_settings() {
  $defaults = array(
    'css_switch' => 0,
    'opengrid_js_control'=> 0,
    'scroll_to_top' => 0,
    'fixed_buttons' => 0,
    'frontpage_layout_checkbox' => 0, 
    'hide_sidebars' => 0 ,
    'auto_hide_messages' => 0,
  );

  // Add site-wide theme settings
  $defaults = array_merge($defaults, theme_get_settings());

  return $defaults;
}

/**
 * Initialize theme settings if needed
 */
function opengrid_initialize_theme_settings($theme_name) {
  $theme_settings = theme_get_settings($theme_name);
  if (!isset($theme_settings['css_switch']) || $theme_settings['opengrid_rebuild_registry'] == 1) {
    static $registry_rebuilt = false;   // avoid multiple rebuilds per page

    // Rebuild theme registry & notify user
    if(isset($theme_settings['opengrid_rebuild_registry']) && $theme_settings['opengrid_rebuild_registry'] == 1 && !$registry_rebuilt) {
      drupal_rebuild_theme_registry();
      drupal_set_message(t('Theme registry rebuild completed. <a href="!link">Turn off</a> this feature for production websites.', array('!link' => url('admin/build/themes/settings/' . $GLOBALS['theme']))), 'warning');
      $registry_rebuilt = true;
    }

    // Retrieve saved or site-wide theme settings
    $theme_setting_name = str_replace('/', '_', 'theme_'. $theme_name .'_settings');
    $settings = (variable_get($theme_setting_name, FALSE)) ? theme_get_settings($theme_name) : theme_get_settings();

    // Skip toggle_node_info_ settings
    if (module_exists('node')) {
      foreach (node_get_types() as $type => $name) {
        unset($settings['toggle_node_info_'. $type]);
      }
    }

    // Combine default theme settings from .info file & theme-settings.php
    $theme_data = list_themes();   // get theme data for all themes
    $info_theme_settings = ($theme_name) ? $theme_data[$theme_name]->info['settings'] : array();
    $defaults = array_merge(opengrid_default_theme_settings(), $info_theme_settings);

    // Set combined default & saved theme settings
    variable_set($theme_setting_name, array_merge($defaults, $settings));

    // Force theme settings refresh
    theme_get_setting('', TRUE);
  }
}

/**
 * Implementation of THEMEHOOK_settings() function.
 *
 * @param $saved_settings
 *   An array of saved settings for this theme.
 * @return
 *   A form array.
 */
function opengrid_settings($saved_settings, $subtheme_defaults = array()) {

  global $base_url;
  
  // Get theme name from url (admin/.../theme_name)
  $theme_name = arg(count(arg()) - 1);
  
  // Combine default theme settings from .info file & theme-settings.php
  $theme_data = list_themes();   // get data for all themes
  $info_theme_settings = ($theme_name) ? $theme_data[$theme_name]->info['settings'] : array();
  $defaults = array_merge(opengrid_default_theme_settings(), $info_theme_settings);

  // Allow a subtheme to override the default values.
  $defaults = array_merge($defaults, $subtheme_defaults); 

  // Combine default and saved theme settings
  $settings = array_merge($defaults, $saved_settings);
  
  // Create the form using Forms API: http://api.drupal.org/api/6
  $form = array();

  $form['opengrid_rebuild_registry'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Rebuild theme registry on every page.'),
    '#default_value' => $settings['opengrid_rebuild_registry'],
    '#description'   => t('During theme development, it can be very useful to continuously <a href="!link">rebuild the theme registry</a>. WARNING: this is a huge performance penalty and must be turned off on production websites.', array('!link' => 'http://drupal.org/node/173880#theme-registry')),
    '#prefix'        => '<div id="div-zen-registry"><strong>' . t('Theme registry:') . '</strong>',
    '#suffix'        => '</div>',
  );
  
  $form['auto_hide_messages'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Auto hide status messages.'),
    '#default_value' => $settings['auto_hide_messages'],
  );  

  $form['scroll_to_top'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Scroll to top Button.'),
    '#default_value' => $settings['scroll_to_top'],
  );
  
  $form['hide_sidebars'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Hide/Show sidebars.'),
    '#default_value' => $settings['hide_sidebars'],
    '#description'   => t('Useful for those admin pages with big tables.'),
  );
  
  $form['fixed_buttons'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Fixed Submit buttons.'),
    '#default_value' => $settings['fixed_buttons'],
    '#description' => t('Set a fixed position for submit buttons on node forms(useful in long forms).'),
  );  

  $form['frontpage_layout_checkbox'] = array(
    '#type'          => 'checkbox',
    '#title'         => t('Front Page Layout.'),
    '#default_value' => $settings['frontpage_layout_checkbox'],
    '#description' => t('Set an exclusive layout for the front page.'),
  ); 

  //primary and secondary links

  $form['main_navigation'] = array(
    '#type' => 'fieldset',
    '#title' => t('Grid Settings for Primary & Secondary Links wrapper.'),
  );
  $form['main_navigation']['primary_dropdown'] = array(
    '#type' => 'checkbox',
    '#title' => t('Dropdown Menu'),
    '#default_value' => $settings['primary_dropdown'],
    '#prefix' => '<div class="inline-label">',
    '#suffix' => '</div>',  
  );
  $form['main_navigation']['navigation_extras'] = array(
    '#type' => 'textfield',
    '#title' => t('Extra classes'),
    '#size' => 20,
    '#default_value' => $settings['navigation_extras'],
    '#prefix' => '<div class="inline-label">',
    '#suffix' => '</div>',
  );
  
  $nav_classes = array('none' => 'none','emac' => 'emac','drupal1' => 'drupal1','simpleTabs' => 'Simple Tabs');
  $form['main_navigation']['navigation_classes'] = array(
    '#type' => 'select',
    '#title' => t('Default classes'),
    '#options' => $nav_classes,
    '#default_value' => $settings['navigation_classes'],
    '#prefix' => '<div class="inline-label">',
    '#suffix' => '</div>',
  );  

  //containers settings form

  $form['containers_fieldset'] = array(
    '#type' => 'fieldset',
    '#title' => t('Container Settings'),
    '#collapsible' => TRUE,
    '#description' => t('Container define the number of columns in wich is split the screen.'),
  );
  
  $form['containers_fieldset']['container_columns'] = array(
    '#type' => 'select',
    '#title' => t('Grid columns'),
    '#attributes' => array('class' => 'input-inline'),
    '#options' => array(
	'none' => t('none'),
	'container_12' => t('12'), 
	'container_16' => t('16'), 
	'container_24' => t('24'),
    ),
    '#default_value' => $settings['container_columns'],
    '#prefix' => '<div class="inline-label">',
    '#suffix' => '</div>',    
  );
  
  $form['containers_fieldset']['css_switch'] = array(
    '#type' => 'select',
    '#title' => t('Select CSS'),
    '#options' => array(t('fixed'), t('fluid')),
    '#default_value' => $settings['css_switch'],
    '#prefix' => '<div class="inline-label">',
    '#suffix' => '</div>',    
  );  
  
  $form['containers_fieldset']['container_extras'] = array(
    '#type' => 'textfield',
    '#title' => t('Container extras'),
    '#attributes' => array('class' => 'input-inline'),
    '#size' => 20,
    '#default_value' => $settings['container_extras'],
    '#prefix' => '<div class="inline-label">',
    '#suffix' => '</div>',    
  );    
  
  $form['containers_fieldset']['independent_containers'] = array(
    '#type' => 'checkbox',
    '#title' => t('Container by Region'),
    '#description' => t('Set Independent Containers for each Region, this is usefull for design that needs full screen width backgrounds.'),
    '#default_value' => $settings['independent_containers'],
    '#prefix' => '<div class="inline-label">',
    '#suffix' => '</div>',    
  );
  
  //For independent containers set the number of columns
  $containers = array(
      'header_classes' => t('Header container'),
      'content_top_classes' => t('Content Top container'),
      'content_classes' => t('Content container'),
      'content_bottom_classes' => t('Content Bottom container'),
      'footer_classes' => t('Footer container'),
  );
    
  foreach($containers as $key => $name){  
    //$Key_name = str_replace('_', ' ',$key);
    $form['containers_fieldset']['independent_containers_values'][$key] = array(
      '#type' => 'select',
      '#title' => t('@key_name ',array('@key_name' => $name)),
      '#options' => array(
	'none' => t('none'),
	'container_12' => t('12'), 
	'container_16' => t('16'), 
	'container_24' => t('24'),
      ),
      '#default_value' => $settings[$key] ? $settings[$key] : $settings['container_columns'],      
    );
  }
  // grid settings form

  $grid_options = array(
    'header',
    'content_top',
    'content',
    'main',
    'first_sidebar',
    'second_sidebar',
    'content_bottom',
    'footer',
  );

  $layouts = array(
    'both_sidebars',
    'first_sidebar',
    'second_sidebar',
    'no_sidebars',
    'frontpage'
  );
  $form['help_message'] = array(
    '#type' => 'markup',
    '#value' => '<h3>'. t('Pre-configuration for layout based on active sidebars.') .'</h3>',
  );
  
  foreach ($layouts as $key) {
    $new_grid_options = $grid_options;
    if ($key == 'no_sidebars' || $key == 'first_sidebar') {
      unset($new_grid_options[5]);
    }
    if ($key == 'no_sidebars' || $key == 'second_sidebar') {
      unset($new_grid_options[4]);
    }

    $name = str_replace('_', ' ',$key);
    $form[$key .'_layout'] = array(
      '#type' => 'fieldset',
      '#title' => t('@name Active', array('@name' => $name)),
      '#collapsible' => true,
      '#collapsed' => true,
      '#tree' => true,
    );

    // Grids Fieldset
    $form[$key .'_layout']['grids_settings'] = array(
      '#type' => 'fieldset',
      '#theme' => 'grids_settings_table',
    );
    $max_columns = ($settings['container_columns'] == 'container_12') ? 12 : 16;
    $max_columns = ($settings['container_columns'] == 'container_24') ? 24 : 16;    
    for ($i = 0; $i <= $max_columns; $i++) {
      $options_16[$i] = $i == 0 ? t('none') : $i;
    }

    foreach ($new_grid_options as $key_region) {
      $name = str_replace('_', ' ',$key_region);
      $form[$key .'_layout']['grids_settings'][$key_region .'_grid']['grid'] = array(
        '#type' => 'select',
        '#title' => t('@name', array('@name' => $name)),
        '#attributes' => array('class' => 'input-inline'),
        '#options' => $options_16,
        '#default_value' => $settings[$key .'_layout']['grids_settings'][$key_region .'_grid']['grid'],
      );

      // prefix, suffix settings
      $form[$key .'_layout']['grids_settings'][$key_region .'_grid']['prefix'] = array(
        '#type' => 'select',
        '#attributes' => array('class' => 'input-inline'),
        '#options' => $options_16,
        '#default_value' => $settings[$key .'_layout']['grids_settings'][$key_region .'_grid']['prefix'],
      );

      $form[$key .'_layout']['grids_settings'][$key_region .'_grid']['suffix'] = array(
        '#type' => 'select',
        '#attributes' => array('class' => 'input-inline'),
        '#options' => $options_16,
        '#default_value' => $settings[$key .'_layout']['grids_settings'][$key_region .'_grid']['suffix'],
      );

      // push , pulls selects
      $form[$key .'_layout']['grids_settings'][$key_region .'_grid']['push'] = array(
        '#type' => 'select',
        '#attributes' => array('class' => 'input-inline'),
        '#options' => $options_16,
        '#default_value' => $settings[$key .'_layout']['grids_settings'][$key_region .'_grid']['push'],
      );

      $form[$key .'_layout']['grids_settings'][$key_region .'_grid']['pull'] = array(
        '#type' => 'select',
        '#attributes' => array('class' => 'input-inline'),
        '#options' => $options_16,
        '#default_value' => $settings[$key .'_layout']['grids_settings'][$key_region .'_grid']['pull'],
      );

      // alpha, omega checkboxes
      $form[$key .'_layout']['grids_settings'][$key_region .'_grid']['alpha'] = array(
        '#type' => 'checkbox',
        '#attributes' => array('class' => 'input-inline'),
        '#default_value' => $settings[$key .'_layout']['grids_settings'][$key_region .'_grid']['alpha'],
      );

      $form[$key .'_layout']['grids_settings'][$key_region .'_grid']['omega'] = array(
        '#type' => 'checkbox',
        '#attributes' => array('class' => 'input-inline'),
        '#default_value' => $settings[$key .'_layout']['grids_settings'][$key_region .'_grid']['omega'],
      );

      // extra classes textfield
      $form[$key .'_layout']['grids_settings'][$key_region .'_grid']['extras'] = array(
        '#type' => 'textfield',
        '#attributes' => array('class' => 'input-inline'),
        '#size' => 10,
        '#default_value' => $settings[$key .'_layout']['grids_settings'][$key_region .'_grid']['extras'],
      );
    }
  }

  return $form;
}
